==> material-elements-0.0.2.tgz: package/dist-src/mwc-drawer/mwc-drawer-base.js <==
/**
@license
Copyright 2018 Google Inc. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
import { __decorate } from "tslib/tslib.es6.js"; // Note this blocking-elements import is not redundant with the one below,
// because we need to ensure we import this module at runtime for its
// side-effects. See
// https://github.com/Microsoft/TypeScript/wiki/FAQ#why-are-imports-being-elided-in-my-emit.

import "blocking-elements/dist/blocking-elements.js";
import "wicg-inert/src/inert.js";
import { strings } from "../drawer/constants.js";
import MDCDismissibleDrawerFoundation from "../drawer/dismissible/foundation.js";
import MDCModalDrawerFoundation from "../drawer/modal/foundation.js";
import { addHasRemoveClass, BaseElement, observer } from "../mwc-base/base-element.js";
import { html, property, query } from "./node_modules/lit-element/lit-element.js";
import { classMap } from "./node_modules/lit-html/directives/class-map.js";
const blockingElements = document.$blockingElements;
export class DrawerBase extends BaseElement {
  constructor() {
    super(...arguments);
    this._previousFocus = null;
    this.open = false;
    this.hasHeader = false;
    this.type = '';
  }

  get mdcFoundationClass() {
    return this.type === 'modal' ? MDCModalDrawerFoundation : MDCDismissibleDrawerFoundation;
  }

  createAdapter() {
    return Object.assign(Object.assign({}, addHasRemoveClass(this.mdcRoot)), {
      elementHasClass: (element, className) => element.classList.contains(className),
      saveFocus: () => {
        // Note, casting to avoid cumbersome runtime check.
        this._previousFocus = this.getRootNode().activeElement;
      },
      restoreFocus: () => {
        const previousFocus = this._previousFocus && this._previousFocus.focus;

        if (previousFocus) {
          // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
          this._previousFocus.focus();
        }
      },
      notifyClose: () => {
        this.open = false;
        this.dispatchEvent(new Event(strings.CLOSE_EVENT, {
          bubbles: true,
          cancelable: true
        }));
      },
      notifyOpen: () => {
        this.open = true;
        this.dispatchEvent(new Event(strings.OPEN_EVENT, {
          bubbles: true,
          cancelable: true
        }));
      },
      // TODO(sorvell): Implement list focusing integration.
      focusActiveNavigationItem: () => {},
      trapFocus: () => {
        blockingElements.push(this);
        this.appContent.inert = true;
      },
      releaseFocus: () => {
        blockingElements.remove(this);
        this.appContent.inert = false;
      }
    });
  }

  _handleScrimClick() {
    if (this.mdcFoundation instanceof MDCModalDrawerFoundation) {
      this.mdcFoundation.handleScrimClick();
    }
  }

  render() {
    const dismissible = this.type === 'dismissible' || this.type === 'modal';
    const modal = this.type === 'modal';
    const header = this.hasHeader ? html`
      <div class="mdc-drawer__header">
        <h3 class="mdc-drawer__title"><slot name="title"></slot></h3>
        <h6 class="mdc-drawer__subtitle"><slot name="subtitle"></slot></h6>
        <slot name="header"></slot>
      </div>
      ` : '';
    return html`
      <aside class="mdc-drawer
          ${classMap({
      'mdc-drawer--dismissible': dismissible,
      'mdc-drawer--modal': modal
    })}">
        ${header}
        <div class="mdc-drawer__content"><slot></slot></div>
      </aside>
      ${modal ? html`<div class="mdc-drawer-scrim"
                          @click="${this._handleScrimClick}"></div>` : ''}
      <div class="mdc-drawer-app-content">
        <slot name="appContent"></slot>
      </div>
      `;
  } // note, we avoid calling `super.firstUpdated()` to control when
  // `createFoundation()` is called.


  firstUpdated() {
    this.mdcRoot.addEventListener('keydown', e => this.mdcFoundation.handleKeydown(e));
    this.mdcRoot.addEventListener('transitionend', e => this.mdcFoundation.handleTransitionEnd(e));
  }

  updated(changedProperties) {
    if (changedProperties.has('type')) {
      this.createFoundation();
    }
  }

}

__decorate([query('.mdc-drawer')], DrawerBase.prototype, "mdcRoot", void 0);

__decorate([query('.mdc-drawer-app-content')], DrawerBase.prototype, "appContent", void 0);

__decorate([observer(function (value) {
  if (this.type === '') {
    return;
  }

  if (value) {
    this.mdcFoundation.open();
  } else {
    this.mdcFoundation.close();
  }
}), property({
  type: Boolean,
  reflect: true
})], DrawerBase.prototype, "open", void 0);

__decorate([property({
  type: Boolean
})], DrawerBase.prototype, "hasHeader", void 0);

__decorate([property({
  reflect: true
})], DrawerBase.prototype, "type", void 0);

==> material-elements-0.1.0.tgz: package/dist-src/mwc-drawer/mwc-drawer-base.js <==
/**
@license
Copyright 2018 Google Inc. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
import { __decorate } from "tslib/tslib.es6.js"; // Note this blocking-elements import is not redundant with the one below,
// because we need to ensure we import this module at runtime for its
// side-effects. See
// https://github.com/Microsoft/TypeScript/wiki/FAQ#why-are-imports-being-elided-in-my-emit.

import "blocking-elements/dist/blocking-elements.js";
import "wicg-inert/src/inert.js";
import { strings } from "../drawer/constants.js";
import MDCDismissibleDrawerFoundation from "../drawer/dismissible/foundation.js";
import MDCModalDrawerFoundation from "../drawer/modal/foundation.js";
import { addHasRemoveClass, BaseElement, observer } from "../mwc-base/base-element.js";
import { html, property, query } from "lit-element/lit-element.js";
import { classMap } from "lit-html/directives/class-map.js";
const blockingElements = document.$blockingElements;
export class DrawerBase extends BaseElement {
  constructor() {
    super(...arguments);
    this._previousFocus = null;
    this.open = false;
    this.hasHeader = false;
    this.type = '';
  }

  get mdcFoundationClass() {
    return this.type === 'modal' ? MDCModalDrawerFoundation : MDCDismissibleDrawerFoundation;
  }

  createAdapter() {
    return Object.assign(Object.assign({}, addHasRemoveClass(this.mdcRoot)), {
      elementHasClass: (element, className) => element.classList.contains(className),
      saveFocus: () => {
        // Note, casting to avoid cumbersome runtime check.
        this._previousFocus = this.getRootNode().activeElement;
      },
      restoreFocus: () => {
        const previousFocus = this._previousFocus && this._previousFocus.focus;

        if (previousFocus) {
          // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
          this._previousFocus.focus();
        }
      },
      notifyClose: () => {
        this.open = false;
        this.dispatchEvent(new Event(strings.CLOSE_EVENT, {
          bubbles: true,
          cancelable: true
        }));
      },
      notifyOpen: () => {
        this.open = true;
        this.dispatchEvent(new Event(strings.OPEN_EVENT, {
          bubbles: true,
          cancelable: true
        }));
      },
      // TODO(sorvell): Implement list focusing integration.
      focusActiveNavigationItem: () => {},
      trapFocus: () => {
        blockingElements.push(this);
        this.appContent.inert = true;
      },
      releaseFocus: () => {
        blockingElements.remove(this);
        this.appContent.inert = false;
      }
    });
  }

  _handleScrimClick() {
    if (this.mdcFoundation instanceof MDCModalDrawerFoundation) {
      this.mdcFoundation.handleScrimClick();
    }
  }

  render() {
    const dismissible = this.type === 'dismissible' || this.type === 'modal';
    const modal = this.type === 'modal';
    const header = this.hasHeader ? html`
      <div class="mdc-drawer__header">
        <h3 class="mdc-drawer__title"><slot name="title"></slot></h3>
        <h6 class="mdc-drawer__subtitle"><slot name="subtitle"></slot></h6>
        <slot name="header"></slot>
      </div>
      ` : '';
    return html`
      <aside class="mdc-drawer
          ${classMap({
      'mdc-drawer--dismissible': dismissible,
      'mdc-drawer--modal': modal
    })}">
        ${header}
        <div class="mdc-drawer__content"><slot></slot></div>
      </aside>
      ${modal ? html`<div class="mdc-drawer-scrim"
                          @click="${this._handleScrimClick}"></div>` : ''}
      <div class="mdc-drawer-app-content">
        <slot name="appContent"></slot>
      </div>
      `;
  } // note, we avoid calling `super.firstUpdated()` to control when
  // `createFoundation()` is called.


  firstUpdated() {
    this.mdcRoot.addEventListener('keydown', e => this.mdcFoundation.handleKeydown(e));
    this.mdcRoot.addEventListener('transitionend', e => this.mdcFoundation.handleTransitionEnd(e));
  }

  updated(changedProperties) {
    if (changedProperties.has('type')) {
      this.createFoundation();
    }
  }

}

__decorate([query('.mdc-drawer')], DrawerBase.prototype, "mdcRoot", void 0);

__decorate([query('.mdc-drawer-app-content')], DrawerBase.prototype, "appContent", void 0);

__decorate([observer(function (value) {
  if (this.type === '') {
    return;
  }

  if (value) {
    this.mdcFoundation.open();
  } else {
    this.mdcFoundation.close();
  }
}), property({
  type: Boolean,
  reflect: true
})], DrawerBase.prototype, "open", void 0);

__decorate([property({
  type: Boolean
})], DrawerBase.prototype, "hasHeader", void 0);

__decorate([property({
  reflect: true
})], DrawerBase.prototype, "type", void 0);
